@@ -1,8 +1,7 @@
 from io import BytesIO
 
 from mcap_protobuf.writer import Writer
-from mcap_protobuf.decoder import Decoder
-from mcap.mcap0.stream_reader import StreamReader
+from mcap_protobuf.reader import read_protobuf_messages
 
 import pytest
 from google.protobuf.timestamp_pb2 import Timestamp
@@ -12,15 +11,16 @@ from google.protobuf.duration_pb2 import Duration
 def test_write_one():
     io = BytesIO()
     with Writer(io) as writer:
-        writer.write_message("timestamps", Timestamp(seconds=5, nanos=10))
+        writer.write_message("timestamps", Timestamp(seconds=5, nanos=10), log_time=15)
     io.seek(0)
 
-    messages = list(Decoder(StreamReader(io)).messages)
+    messages = list(read_protobuf_messages(io))
     assert len(messages) == 1
-    topic, message = messages[0]
-    assert message.seconds == 5
-    assert message.nanos == 10
-    assert topic == "timestamps"
+    message = messages[0]
+    assert message.proto_msg.seconds == 5
+    assert message.proto_msg.nanos == 10
+    assert message.log_time_ns == 15
+    assert message.topic == "timestamps"
 
 
 def test_write_wrong_schema():
